searchNodes=[{"doc":"LiveMotion provides high performance animations declared on the server and run on the client. The main goal of LiveMotion is to make animations as easy as possible by using a simple declarative model to define animations. Traditionally animations have to be defined upfront using CSS transitions and keyframes. This approach requires a lot of context switching and is hard to make dependant on server state. With LiveMotion animations can be declared by using the LiveMotion.motion component. Its's props allow dynamic keyframe animations which can be dependant on the server state. These animations are only declared on the server, but are fully performed on the client . It's just a tiny configuration, which is added via a data-motion attribute. This attribute is picked up by a LiveView JS Hook which performs the animation using the Motion One animation library. Animations happen using the WebAnimations API. Example To declare a simple animation which starts immediately after mount, define the following component. This will rotate the popcorn 🍿 for 360°. def render ( assigns ) do ~H&quot;&quot;&quot; &lt;LiveMotion.motion id=&quot;popcorn&quot; animate={[rotate: 360]}&gt; &lt;span&gt;🍿&lt;/span&gt; &lt;/LiveMotion.motion&gt; &quot;&quot;&quot; end To see all supported options, take a look at the documentation of LiveMotion.motion . Manually triggering animations Animations can also be triggered by user events like button clicks. These animations do not require a round trip to the server and can be defined upfront. Following the previous example: def render ( assigns ) do ~H&quot;&quot;&quot; &lt;div&gt; &lt;LiveMotion.motion id=&quot;popcorn&quot;&gt; &lt;span&gt;🍿&lt;/span&gt; &lt;/LiveMotion.motion&gt; &lt;button phx-click={LiveMotion.JS.toggle( to: &quot;#popcorn&quot;, [ in: [opacity: 1], out: [opacity: 0] ] )}&gt;Toggle me&lt;/button&gt; &lt;/div&gt; &quot;&quot;&quot; end This will toggle the opacity from the #popcorn element. See LiveMotion.JS for more information on how to manually trigger animations. Limitations LiveMotion is still in the early days, so breaking changes are expected. Additionally, there are still a few limitations, which will be added in future releases. LiveMotion.motion always renders as a div element. There are plans on providing an api to support rendering any HTML element. Currently standard easing functions (e.g. ease-in-out , bezier curves) and spring animations are supported. Due to the nature of spring animations, they do not have a fixed duration (theoretically they can run indefinetely). When using unmount transition, this adds a challenge, as we do not know how long Phoenix LiveView should defer the actual removal of the DOM node. For now, we fall back to the maximum supported duration of ten seconds. Support Stagger and glide animations will be added in a later release. Layout animations are not yet supported. Think of animations which automatically move items in the correct place after an element is removed which affects the layout.","ref":"LiveMotion.html","title":"LiveMotion","type":"module"},{"doc":"This is the main component for declaring animations. Tip As LiveMotion uses Motion One to perform the animations, keyframes and transition options will be passed directly to Motion One. For a more complete reference, have a look at their documentation of the animate function . Props id : Required . A unique dom element id for the component. initial : Defines the initial style for the component. Useful when using mount transitions and you want the component to have an initial state to animate to. Accepts a keyframe keyword list. If set to false it will directly apply the styles defined in the animate prop and skip the animation. animate : Defines the target animation style. Accepts a keyframe keyword list. transition : Additional options to specify the behaviour of the animation. These are things like the easing function, duration and delay. exit : The target animation to animate to when the component is unmounted. Accepts the same options as animate does. Keyframe A keyframe is represented by a keyword list defining CSS properties. These can one or multiple values. For example: [ x : 200 ] This will animate the component to 200px on the x axis. As previously mentioned, multiple values are supported, too. The following will animate the element on the x axis to each of the values one after another, spreading the steps equally on the duration. [ x : [ 0 , 200 , 50 , 100 ] ] You might have noticed that x itself is not a valid CSS property. In fact, this is a shorthand to make common animation operations easier. x eventually translates to the CSS property transform: translateX(200px) . The following shorthands are supported: x y y scale scaleX scaleY scaleZ rotate rotateX rotateY rotateZ skewX skewY You need to pass the options as a Keyword list and in snake case. Transition options The transition optiona are passed directly to Motion One. The only thing to keep in mind is the format when defining spring animations. Define a spring animation like this: [ ease : [ spring : [ stiffness : 100 , damping : 50 ] ] ] You need to pass the options as a Keyword list and in snake case.","ref":"LiveMotion.html#motion/1","title":"LiveMotion.motion/1","type":"function"},{"doc":"Provides functions for triggering client side animations without a round-trip to the server. The functions in this module follow the same conventions (more or less) like in the Phoenix.LiveView.JS module and are intended to be used instead if you are dealing with animations. Most of the functions return a Phoenix.LiveView.JS struct, so they can be composed with the LiveView utility functions. The following utilities are included: animate - Triggers an animation on an element. toggle - Toggles between two animations. hide - Performs an animation and hides the element from the DOM. show - Shows elements and immediately performs the animation. Consider the following example to hide an element without a round-trip to the server. def popcorn ( assigns ) do ~H&quot;&quot;&quot; &lt;div&gt; &lt;LiveMotion.motion id=&quot;popcorn&quot; initial={[opacity: 1]} exit={[opacity: 0]} &gt; &lt;span&gt;🍿&lt;/span&gt; &lt;/LiveMotion.motion&gt; &lt;button type=&quot;button&quot; phx-click={LiveMotion.JS.hide(to: &quot;#popcorn&quot;)}&gt; Eat popcorn &lt;/button&gt; &lt;/div&gt; &quot;&quot;&quot; end Clicking the &quot;Eat popcorn&quot; button will trigger the exit animation on the motion element. You can also define animations in the call to LiveMotion.JS.hide/1 . See it's documentation for more information.","ref":"LiveMotion.JS.html","title":"LiveMotion.JS","type":"module"},{"doc":"Animates the target. Example def popcorn(assigns) do ~H&quot;&quot;&quot; &lt;div&gt; &lt;div id=&quot;popcorn&quot; style=&quot;font-size: 64px&quot;&gt; &lt;span&gt;🍿&lt;/span&gt; &lt;/div&gt; &lt;button type=&quot;button&quot; phx-click={ LiveMotion.JS.animate( [rotate: [0, 20, -10, 30, -10, 0]], [duration: 0.5], to: &quot;#popcorn&quot; ) } &gt; Shake it! &lt;/button&gt; &lt;/div&gt; &quot;&quot;&quot; Options to - The query selector on which element to perform the animation. If the option is not provided, the target element will be used.","ref":"LiveMotion.JS.html#animate/3","title":"LiveMotion.JS.animate/3","type":"function"},{"doc":"Performs an animation and hides an element after the animation has finished. Triggers the exit animation defined on the target. Additionally allows keyframes and transition to be defined. These will be used to animate the target element and therefore the target does not require to be a LiveMotion.motion component. Options to - The query selector on which element to perform the animation. If the option is not provided, the target element will be used. keyframes - The keyframe keyword list defining the animations. transition - Transition options.","ref":"LiveMotion.JS.html#hide/1","title":"LiveMotion.JS.hide/1","type":"function"},{"doc":"Animates between two animation states. Example def popcorn(assigns) do ~H&quot;&quot;&quot; &lt;div&gt; &lt;div id=&quot;popcorn&quot; style=&quot;font-size: 64px&quot;&gt; &lt;span&gt;🍿&lt;/span&gt; &lt;/div&gt; &lt;button type=&quot;button&quot; phx-click={ LiveMotion.JS.toggle( [ in: [x: -200], out: [x: 200] ], [], to: &quot;#popcorn&quot; ) } &gt; Move popcorn &lt;/button&gt; &lt;/div&gt; &quot;&quot;&quot; Options to - The query selector on which element to perform the animation. If the option is not provided, the target element will be used.","ref":"LiveMotion.JS.html#toggle/3","title":"LiveMotion.JS.toggle/3","type":"function"},{"doc":"Represents configuration for LiveMotion animations.","ref":"LiveMotion.Motion.html","title":"LiveMotion.Motion","type":"module"}]